# simple plotting + fitting
Doc: https://apn-pucky.github.io/smpl/index.html

[![PyPI version](https://badge.fury.io/py/smpl.svg)](https://badge.fury.io/py/smpl)
![workflow](https://github.com/APN-Pucky/smpl/actions/workflows/stable.yml/badge.svg)
![downloads](https://img.shields.io/pypi/dm/smpl.svg)

### stable version
```
pip install smpl
```
Optional: --user or --upgrade

### unstable version
```
pip install --index-url https://test.pypi.org/simple/ smpl
```
